mailr22762 - /trunk/specific_analyses/frame_order/uf.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on April 15, 2014 - 09:18:
Author: bugman
Date: Tue Apr 15 09:18:35 2014
New Revision: 22762

URL: http://svn.gna.org/viewcvs/relax?rev=22762&view=rev
Log:
Fixes for the frame_order.pivot user function - the model parameters were not 
being updated.

The update_model() function is now called to make sure that the pivot point 
is either added or
removed from the list of model parameters.


Modified:
    trunk/specific_analyses/frame_order/uf.py

Modified: trunk/specific_analyses/frame_order/uf.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/specific_analyses/frame_order/uf.py?rev=22762&r1=22761&r2=22762&view=diff
==============================================================================
--- trunk/specific_analyses/frame_order/uf.py   (original)
+++ trunk/specific_analyses/frame_order/uf.py   Tue Apr 15 09:18:35 2014
@@ -414,8 +414,10 @@
     # Store the fixed flag.
     cdp.pivot_fixed = fix
 
     # No pivot given, so quit.
     if pivot == None:
+        if hasattr(cdp, 'model'):
+            update_model()
         return
 
     # Convert the pivot to a numpy array.
@@ -440,6 +442,10 @@
         setattr(cdp, name_y, pivot[1])
         setattr(cdp, name_z, pivot[2])
 
+    # Update the model.
+    if hasattr(cdp, 'model'):
+        update_model()
+
 
 def quad_int(flag=False):
     """Turn the high precision Scipy quadratic numerical integration on or 
@@ -414,8 +414,10 @@
     cdp.pivot_fixed = fix
 
-    # No pivot given, so quit.
+    # No pivot given, so update the model if needed and quit.
     if pivot == None:
off.




Related Messages


Powered by MHonArc, Updated Tue Apr 15 09:40:02 2014